`.getOnt` <-
function(gene, ontology, dropCodes) {
    allGO<-GOENTREZID2GO[[gene]]
	
    if(!is.null(dropCodes)) {
        evidence<-sapply(allGO, function(x) x$Evidence)
        drop<-evidence %in% dropCodes
        allGO<-allGO[!drop]
    }

    category<-sapply(allGO, function(x) x$Ontology)
    unlist(unique(names(allGO[category %in% ontology])))
}

`.getSim` <-
function(GOID1, GOID2, ont, measure, db) { 
    rootCount<-switch(ont, 
        MF=.gocount["GO:0003674", db],
        BP=.gocount["GO:0008150", db],
        CC=.gocount["GO:0005575", db] )

    p1<-.gocount[GOID1, db]/rootCount
    p2<-.gocount[GOID2, db]/rootCount
    if(p1 == 0 || p2 == 0) return(NA)

    dataenv<-get(paste("GO", ont, "ANCESTOR", sep=""), mode="environment")
    ancestor1<-c(GOID1, get(GOID1, dataenv))
    ancestor2<-c(GOID2, get(GOID2, dataenv))
    commonAncestor<-intersect(ancestor1, ancestor2)

    pms<-min(.gocount[commonAncestor, db], na.rm=TRUE)/rootCount

    sim<-switch(measure,
        Resnik=-log(pms),
        Lin=2*log(pms)/(log(p1)+log(p2)),
        Jiang=2*log(pms)-log(p1)-log(p2), 
        Rel=(2*log(pms)/(log(p1)+log(p2)))*(1-pms) )

    return(round(sim, digits=3))
}






